SNCosmo
=======

*Python library for supernova cosmology*

[![Build Status](https://github.com/sncosmo/sncosmo/actions/workflows/run_tests.yml/badge.svg)](https://github.com/sncosmo/sncosmo/actions/workflows/run_tests.yml)
[![Coverage Status](https://codecov.io/gh/sncosmo/sncosmo/branch/master/graph/badge.svg?token=jMdsK7kgPb)](https://codecov.io/gh/sncosmo/sncosmo)
[![Documentation Status](https://readthedocs.org/projects/sncosmo/badge/?version=latest)](https://sncosmo.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/sncosmo.svg?style=flat-square)](https://pypi.python.org/pypi/sncosmo)
[![Anaconda](https://anaconda.org/conda-forge/sncosmo/badges/version.svg)](https://anaconda.org/conda-forge/sncosmo)
[![ASCL](https://img.shields.io/badge/ascl-1611.017-blue.svg?colorB=262255)](https://ascl.net/1611.017)

**Documentation:** http://sncosmo.readthedocs.io

**Citing sncosmo:** [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.592747.svg)](https://doi.org/10.5281/zenodo.592747)
